@@ -140,11 +140,25 @@ impl<'a> Display for DesktopEntry<'a> {
     }
 }
 
-pub fn default_paths() -> Vec<PathBuf> {
+pub enum PathSource {
+    Local,
+    LocalDesktop,
+    LocalFlatpak,
+    System,
+    SystemFlatpak,
+    SystemSnap,
+}
+
+pub fn default_paths() -> Vec<(PathSource, PathBuf)> {
     let home_dir = dirs::home_dir().unwrap();
 
     vec![
-        PathBuf::from("/usr/share/applications"),
-        home_dir.join(".local/share/applications"),
+        (PathSource::System, PathBuf::from("/usr/share/applications")),
+        (PathSource::SystemFlatpak, PathBuf::from("/var/lib/flatpak/exports/share/applications")),
+        (PathSource::SystemSnap, PathBuf::from("/var/lib/snapd/desktop/applications")),
+        (PathSource::Local, home_dir.join(".local/share/applications")),
+        (PathSource::LocalDesktop, home_dir.join("Desktop")),
+        (PathSource::LocalFlatpak, PathBuf::from(".local/share/flatpak/exports/share/applications"))
+
     ]
 }
